===================
OS-Faults |release|
===================

**OpenStack fault-injection library**

OS-Faults library provides an unified abstract API for performing
destructive actions against OpenStack cloud. The library is extendable
using drivers. Basic drivers for DevStack, Linux services and power
management are already included.


Contents
========

.. toctree::
   :maxdepth: 3

   quickstart/index
   cli
   drivers
   api
   contributing

Release Notes
=============

.. toctree::
   :maxdepth: 1

   history

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

